==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapScopeEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapScopeEntity.AbstractMapScopeEntity implements org.keycloak.models.map.authorization.entity.MapScopeEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> entityFieldDelegate;
    public MapScopeEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIconUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setIconUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapScopeEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapScopeEntity.AbstractMapScopeEntity implements org.keycloak.models.map.authorization.entity.MapScopeEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> entityFieldDelegate;
    public MapScopeEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapScopeEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIconUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setIconUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID, p0);
    }
}
